<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\CustomField;

use Akeeba\TicketSystem\Admin\Model\CustomFields;
use JText;
use JFactory;

defined('_JEXEC') or die();

/**
 * A single checkbox field
 *
 * @author Nicholas K. Dionysopoulos
 */
class Checkbox extends Base
{
	public function getField($item, $cache, $userparams)
	{
		$default = strtoupper(trim($item->default));

		switch ($default)
		{
			case 'YES':
			case 'TRUE':
			case 'ON':
			case '1':
			case 'ENABLED':
			case 'CHECKED':
			case 'SELECTED':
				$default = 1;
				break;

			default:
				$default = 0;
				break;
		}

		// Get the current value
		if (array_key_exists($item->slug, $cache['params']))
		{
			$current = $cache['params'][ $item->slug ];
		}
		else
		{
			if (!is_object($userparams->params))
			{
				$current = $default;
			}
			else
			{
				$slug    = $item->slug;
				$current = property_exists($userparams->params, $item->slug) ? $userparams->params->$slug : $default;
			}
		}

		// Is this a required field?
		$required = $item->allow_empty ? '' : '* ';

		// Parse value
		if ($current)
		{
			$checked = 'checked="checked"';
		}
		else
		{
			$checked = '';
		}

		// Set up field's HTML content
		$html = '<input type="checkbox" name="params[' . $item->slug . ']" id="' . $item->slug . '" ' . $checked . ' />';

		// Setup the field
		$field = array(
			'id'          => $item->slug,
			'label'       => $required . JText::_($item->title),
			'elementHTML' => $html,
			'isValid'     => $required ? !empty($current) : true
		);

		if ($item->invalid_label)
		{
			$field['invalidLabel'] = JText::_($item->invalid_label);
		}

		if ($item->valid_label)
		{
			$field['validLabel'] = JText::_($item->valid_label);
		}

		return $field;
	}

	public function validate($item, &$custom)
	{
		if (!is_array($custom) || !array_key_exists($item->slug, $custom))
		{
			$custom[ $item->slug ] = 0;
		}

		$valid = true;

		if (!$item->allow_empty)
		{
			$valid = $custom[ $item->slug ];
		}

		return $valid ? 1 : 0;
	}

	public function getDisplay(CustomFields $item, $value)
	{
		return strtolower($value) == 'on' ? JText::_('JYES') : JText::_('JNO');
	}
}
