<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Helper;

use FOF30\Container\Container;
use JComponentHelper;
use JFactory;
use JLoader;

defined('_JEXEC') or die;

/**
 * A helper class to quickly get the component parameters
 */
abstract class ComponentParams
{

	private static function getContainer()
    {
    	return Container::getInstance('com_ats');
    }

	/**
	 * Clears the internal cache, forcing the object to relaod the params directly from the database
	 */
	public static function purge()
	{
		$container = self::getContainer();

		$container->params->reload();
	}


	/**
	 * Returns the value of a component configuration parameter
	 *
	 * @param   string $key     The parameter to get
	 * @param   mixed  $default Default value
	 *
	 * @return  mixed
	 */
	public static function getParam($key, $default = null)
	{
		$container = self::getContainer();

		return $container->params->get($key, $default);
	}

	/**
	 * Sets the value of a component configuration parameter
	 *
	 * @param   string $key    The parameter to set
	 * @param   mixed  $value  The value to set
	 *
	 * @return  void
	 */
	public static function setParam($key, $value)
	{
		$container = self::getContainer();

		$container->params->set($key, $value);
		$container->params->save();
	}

	public static function getCustomTicketStatuses()
	{
		static $statuses = '';

		if (is_array($statuses))
		{
			return $statuses;
		}
		else
		{
			$statuses = array();
		}

		// Let's prime the statuses variable as an array, so next time I can simply skip the following code
		$statuses = array();
		$custom   = self::getParam('customStatuses', '');
		$custom   = str_replace("\\n" , "\n", $custom);
		$custom   = str_replace("\r"  , "\n", $custom);
		$custom   = str_replace("\n\n", "\n", $custom);

		$lines = explode("\n", $custom);

		foreach($lines as $line)
		{
			$parts = explode('=', $line);

			if(count($parts) != 2)
			{
				continue;
			}

			$statuses[$parts[0]] = $parts[1];
		}

		return $statuses;
	}
}
